@@ -4,11 +4,11 @@ Admin's option for all model defined in customadmin app.
 from django.contrib import admin
 from django import forms
 from upy.contrib.customadmin.models import CustomAdmin, CustomApp, CustomLink, _, \
-                                            list_apps,list_models,CustomModel, all_apps
-from upy.contrib.image.admin import PositionImageAdmin
+    list_apps, list_models, CustomModel, all_apps
+from upy.contrib.sortable.admin import PositionAdmin
 from upy.utils import upy_re_match
 from django.conf import settings
-
+from upy.contrib.image.admin import AdminThumbnail, ColorBoxPositionAdmin
 
 
 def cleaning_color_picker(form, fields):
@@ -17,9 +17,9 @@ def cleaning_color_picker(form, fields):
     """
     chk = True
     for field in fields:
-        
+
         if form.cleaned_data[field] and not upy_re_match(r'^[0-9a-fA-F]+$',
-                                            "%s" % form.cleaned_data[field]):
+                                                         "%s" % form.cleaned_data[field]):
             chk = False
             form._errors[field] = form.error_class(
                 [_(u'You must compile this field with hexadecimal characters')])
@@ -29,11 +29,13 @@ def cleaning_color_picker(form, fields):
                 [_(u'You must compile this field with six hexadecimal characters')])
     return form, chk
 
-class CustomAdminForm(forms.ModelForm): 
+
+class CustomAdminForm(forms.ModelForm):
     """
     It ovverrides CustomAdmin modelform
     """
-    def clean(self): 
+
+    def clean(self):
         cleaned_data = super(CustomAdminForm, self).clean()
         view_mode = cleaned_data['view_mode']
         autocomplete_app_list = cleaned_data['autocomplete_app_list']
@@ -43,7 +45,8 @@ class CustomAdminForm(forms.ModelForm):
                 CustomApp.objects.get(application__iexact="Customadmin")
             except CustomApp.DoesNotExist:
                 msg_view_mode = _(u"You have to define Customadmin in your CustomApp if you use a custom view_mode...")
-                msg_autocomplete_app_list= _(u"...or at least enable autocomplete_app_list which will include Customadmin too.")
+                msg_autocomplete_app_list = _(
+                    u"...or at least enable autocomplete_app_list which will include Customadmin too.")
                 self._errors["view_mode"] = self.error_class([msg_view_mode])
                 self._errors["autocomplete_app_list"] = self.error_class([msg_autocomplete_app_list])
                 # These fields are no longer valid. Remove them from the
@@ -56,8 +59,10 @@ class CustomAdminForm(forms.ModelForm):
             try:
                 CustomModel.objects.get(model__iexact=CustomAdmin._meta.verbose_name_plural)
             except CustomModel.DoesNotExist:
-                msg_view_mode = _(u"You have to define Customadmin in your CustomModel if you use a custom view_mode...")
-                msg_autocomplete_models_list= _(u"...or at least enable autocomplete_models_list which will include Customadmin too.")
+                msg_view_mode = _(
+                    u"You have to define Customadmin in your CustomModel if you use a custom view_mode...")
+                msg_autocomplete_models_list = _(
+                    u"...or at least enable autocomplete_models_list which will include Customadmin too.")
                 self._errors["view_mode"] = self.error_class([msg_view_mode])
                 self._errors["autocomplete_models_list"] = self.error_class([msg_autocomplete_models_list])
                 # These fields are no longer valid. Remove them from the
@@ -66,137 +71,156 @@ class CustomAdminForm(forms.ModelForm):
                 del cleaned_data["autocomplete_models_list"]
                 #raise forms.ValidationError(_("You have to define Customadmin in your CustomApp 
                 #if you use a custom view_mode without autocomplete_app_list"))
-        self, chk = cleaning_color_picker(self, ['bg_header','table_title_bg',
-                                                 'table_title_color','h2_color',
-                                                 'h3_color','link_color',
+        self, chk = cleaning_color_picker(self, ['bg_header', 'table_title_bg',
+                                                 'table_title_color', 'h2_color',
+                                                 'h3_color', 'link_color',
                                                  'link_hover_color'])
         if not chk:
             raise forms.ValidationError(_("Some values are not hexadecimal string"))
         return cleaned_data
 
+
 class CustomAdminAdmin(admin.ModelAdmin):
     """
     Admin's options for CustomAdmin model
     """
-    list_display = ('customization','branding','branding_link',
-                    'default','view_mode','autocomplete_app_list','autocomplete_models_list')
-    list_editable = ('branding','branding_link','default','view_mode')
+    list_display = ('customization', 'branding', 'branding_link',
+                    'default', 'view_mode', 'autocomplete_app_list', 'autocomplete_models_list')
+    list_editable = ('branding', 'branding_link', 'default', 'view_mode')
     fieldsets = ((_('Branding'), {'fields':
-                                (('branding', 'branding_link'),
-                                 ('branding_image','default')),
-                    },),
+                                      (('branding', 'branding_link'),
+                                       ('branding_image', 'default')),
+    },),
                  (_('View Option'), {'fields':
-                                (('view_mode', 'use_log_sidebar'),('autocomplete_app_list','autocomplete_models_list')),
-                    },),
+                                         (('view_mode', 'use_log_sidebar'),
+                                          ('autocomplete_app_list', 'autocomplete_models_list')),
+                 },),
                  (_('Images'), {'fields':
-                                (('default_app_image','default_model_image',),),
-                    },),
+                                    (('default_app_image', 'default_model_image',),),
+                 },),
                  (_('Style'), {'fields':
-                                (('bg_header',), ('sitename_font','sitename_font_size',
-                                 'sitename_font_weight'),('table_title_bg','table_title_color'),
-                                 ('h2_color','h2_size'),('h3_color','h3_size'),
-                                 ('link_color','link_hover_color'),
-                                 ),
-                    },),
+                                   (('bg_header',), ('sitename_font', 'sitename_font_size',
+                                                     'sitename_font_weight'), ('table_title_bg', 'table_title_color'),
+                                    ('h2_color', 'h2_size'), ('h3_color', 'h3_size'),
+                                    ('link_color', 'link_hover_color'),
+                                   ),
+                 },),
                  (_('Code'), {'fields':
-                                (('html_head',),('use_css_code',),('css_code',)),
-                    },),
-                 )
+                                  (('html_head',), ('use_css_code',), ('css_code',)),
+                 },),
+    )
     form = CustomAdminForm
     save_on_top = True
+
     class Meta:
         model = CustomAdmin
+
     class Media:
         js = ('/upy_static/customadmin/js/customadmin.js',)
- 
+
+
 class CustomAppForm(forms.ModelForm):
     """
     It overrides admin form for CustomApp model
     """
-    def __init__(self,*args, **kwargs):
+
+    def __init__(self, *args, **kwargs):
         super(CustomAppForm, self).__init__(*args, **kwargs)
         listapps = list_apps()
         if self.instance:
-            listapps.append([self.instance.application]*2)
+            listapps.append([self.instance.application] * 2)
         self.fields['application'].widget = forms.Select(choices=listapps)
-        
+
     class Meta:
         model = CustomApp
-        
-class CustomAppAdmin(PositionImageAdmin):
+
+
+class CustomAppAdmin(ColorBoxPositionAdmin):
     """
     Admin's options for CustomApp model
     """
-    list_display = ('position','application','verbose_app_name',
-                    'show_models','original_image','admin_thumbnail_view',)
-    list_editable = ['position','verbose_app_name','original_image']
-    list_display_links = ['application',]
-    prepopulated_fields = {'verbose_app_name': ('application',)}    
-    
+    admin_thumbnail = AdminThumbnail(image_field='thumb')
+    list_display = ('position', 'application', 'verbose_app_name',
+                    'show_models', 'image', 'admin_thumbnail',)
+    list_editable = ['position', 'verbose_app_name', 'image']
+    list_display_links = ['application', ]
+    prepopulated_fields = {'verbose_app_name': ('application',)}
+
     fieldsets = ((_('Icons'), {'fields':
-                                (('application', 'verbose_app_name'),
-                                 ('original_image'),('show_models',),),
-                    },),
-                 )
+                                   (('application', 'verbose_app_name'),
+                                    ('image',), ('show_models',),),
+    },),
+    )
     save_on_top = True
     form = CustomAppForm
+
     class Meta:
         model = CustomApp
-        
-class CustomLinkAdmin(PositionImageAdmin):
+
+
+class CustomLinkAdmin(ColorBoxPositionAdmin):
     """
     Admin's options for CustomLink model
     """
-    list_display = ('position','link_url','verbose_url_name','admin_thumbnail_view',)
-    list_editable = ['position','verbose_url_name',]
-    list_display_links = ['link_url',]
-    prepopulated_fields = {'verbose_url_name': ('link_url',)}    
-    
+    admin_thumbnail = AdminThumbnail(image_field='thumb')
+    list_display = ('position', 'link_url', 'verbose_url_name', 'admin_thumbnail',)
+    list_editable = ['position', 'verbose_url_name', ]
+    list_display_links = ['link_url', ]
+    prepopulated_fields = {'verbose_url_name': ('link_url',)}
+
     fieldsets = ((_('Icons'), {'fields':
-                                (('link_url', 'verbose_url_name'),('original_image'),),
-                    },),
-                 )
+                                   (('link_url', 'verbose_url_name'), ('image',),),
+    },),
+    )
     save_on_top = True
+
     class Meta:
         model = CustomLink
 
+
 class CustomModelForm(forms.ModelForm):
     """
     It overrides admin form for CustomModel model
     """
-    def __init__(self,*args, **kwargs):
+
+    def __init__(self, *args, **kwargs):
         super(CustomModelForm, self).__init__(*args, **kwargs)
         listmodels = list_models()
         listapps = all_apps()
         print listapps
         if self.instance.pk:
-            listmodels.append([self.instance.model]*2)
+            listmodels.append([self.instance.model] * 2)
         self.fields['model'].widget = forms.Select(choices=listmodels)
         self.fields['app'].widget = forms.Select(choices=listapps)
-        
+
     class Meta:
         model = CustomModel
-        
-class CustomModelAdmin(PositionImageAdmin):
+
+
+class CustomModelAdmin(ColorBoxPositionAdmin):
     """
     Admin's options for CustomModel model
     """
-    list_display = ('position','app','model','original_image','admin_thumbnail_view',)
-    list_editable = ['position','original_image']
-    list_display_links = ['model',]
+    admin_thumbnail = AdminThumbnail(image_field='thumb')
+    list_display = ('position', 'app', 'model', 'image', 'admin_thumbnail',)
+    list_editable = ['position', 'image']
+    list_display_links = ['model', ]
     list_filter = ('app',)
     fieldsets = ((_('Icons'), {'fields':
-                                (('app','model',),
-                                 ('original_image'),),
-                    },),
-                 )
+                                   (('app', 'model',),
+                                    ('image',),),
+    },),
+    )
     save_on_top = True
     form = CustomModelForm
+
     class Meta:
         model = CustomModel
+
     class Media:
-        js = (settings.JQUERY_LIB,'/upy_static/customadmin/js/custommodel.js',)
-    
+        js = ColorBoxPositionAdmin.Media.js + ('/upy_static/customadmin/js/custommodel.js',)
+
+
 admin.site.register(CustomAdmin, CustomAdminAdmin)
 admin.site.register(CustomApp, CustomAppAdmin)
 admin.site.register(CustomLink, CustomLinkAdmin)
